pub struct CompletionContext {
pub arguments: Option<HashMap<String, String>>,
pub context_path: Option<String>,
pub preferences: Option<HashMap<String, Value>>,
}Expand description
Completion context for additional information
Struct can be extended to provide additional context for completion requests, such as current file paths, user preferences, etc.
Fields
arguments: Option<HashMap<String, String>>Additional context arguments
context_path: Option<String>Current working directory or context path
preferences: Option<HashMap<String, Value>>User preferences for completion
Implementations
Sourceimpl CompletionContext
impl CompletionContext
Sourcepub fn with_arguments(self, arguments: HashMap<String, String>) -> Self
pub fn with_arguments(self, arguments: HashMap<String, String>) -> Self
Set context arguments
Sourcepub fn with_context_path<S: Into<String>>(self, path: S) -> Self
pub fn with_context_path<S: Into<String>>(self, path: S) -> Self
Set context path
Sourcepub fn with_preferences(self, preferences: HashMap<String, Value>) -> Self
pub fn with_preferences(self, preferences: HashMap<String, Value>) -> Self
Set user preferences