CompositeCompletionHandler

Struct CompositeCompletionHandler 

pub struct CompositeCompletionHandler { /* private fields */ }
Combined completion handler that delegates to different handlers based on reference type

This handler allows you to combine multiple completion handlers and route completion requests to the appropriate handler based on the reference type.

Example

use prism_mcp_rs::core::completion::*;
use std::collections::HashMap;

let prompt_handler = PromptCompletionHandler::new(vec!["analyze".to_string()]);
let resource_handler = ResourceUriCompletionHandler::new(vec![]);
let tool_handler = ToolCompletionHandler::new(HashMap::new());

let combined = CompositeCompletionHandler::new()
.with_prompt_handler(prompt_handler)
.with_resource_handler(resource_handler)
.with_tool_handler(tool_handler);

Implementations

Source

impl CompositeCompletionHandler

pub fn new() -> Self

Create a new combined completion handler

pub fn add_handler<H>( &mut self, reference_type: String, handler: H, ) -> &mut Self
where H: CompletionHandler + 'static,

Add a handler for a specific reference type

Arguments
  • reference_type - The reference type this handler supports (e.g., “ref/prompt”)
  • handler - The completion handler
pub fn with_handler<H>( self, reference_type: impl Into<String>, handler: H, ) -> Self
where H: CompletionHandler + 'static,

Add a handler for a specific reference type (builder pattern)

Arguments
  • reference_type - The reference type this handler supports (e.g., “ref/prompt”)
  • handler - The completion handler
pub fn with_prompt_handler<H: CompletionHandler + 'static>( self, handler: H, ) -> Self

Set the prompt completion handler

pub fn with_resource_handler<H: CompletionHandler + 'static>( self, handler: H, ) -> Self

Set the resource completion handler

pub fn with_tool_handler<H: CompletionHandler + 'static>( self, handler: H, ) -> Self

Set the tool completion handler